translate.storage.xml_extract.extract.Translatable

Package translate :: Package storage :: Package xml_extract :: Module extract :: Class Translatable |
[hide private]
[frames] | no frames]

# Class Translatable

source code

A node corresponds to a translatable element. A node may have children, which correspond to placeables.

Instance Methods | [hide private]
__init__(self, placeable_name, xpath, dom_node, source) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
_get_placeables(self) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
| placeables
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, placeable_name, xpath, dom_node, source) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Decorators: `@accepts(Self(), unicode, unicode, etree._Element, [IsOneOf(TranslatableClass, unicode)])` Overrides: object.__init__ (inherited documentation)

Property Details | [hide private]

### placeables Get Method: _get_placeables(self)